/*
 * Copyright 2007 by Kappich Systemberatung, Aachen
 * Copyright 2004 by Kappich+Kni Systemberatung, Aachen
 * 
 * This file is part of de.bsvrz.dav.daf.
 * 
 * de.bsvrz.dav.daf is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.dav.daf is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with de.bsvrz.dav.daf; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package de.bsvrz.dav.daf.communication.dataRepresentation.datavalue;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

/**
 * Diese Klasse stellt die Attribute und Funktionalitten des Datentyps float zur Verfgung.
 *
 * @author Kappich Systemberatung
 * @version $Revision: 5049 $
 */
public class FloatAttribute extends DataValue {

	/** Der Floatwert */
	private float _float;

	/** Erzeugt ein neues Objekt ohne Parameter. Die Parameter werden zu einem Spteren Zeitpunkt ber die read-Methode eingelesen. */
	public FloatAttribute() {
		_type = FLOAT_TYPE;
	}

	/**
	 * Erzeugt ein neues Objekt mit den gegebenen Parametern.
	 *
	 * @param f float Wert
	 */
	public FloatAttribute(float f) {
		_type = FLOAT_TYPE;
		_float = f;
	}

	public final Object getValue() {
		return new Float(_float);
	}

	public final DataValue cloneObject() {
		return new FloatAttribute(_float);
	}

	public final String parseToString() {
		return "Float: " + _float + "\n";
	}

	public final void write(DataOutputStream out) throws IOException {
		out.writeFloat(_float);
	}

	public final void read(DataInputStream in) throws IOException {
		_float = in.readFloat();
	}

	/**
	 * Diese Methode prft auf Gleichheit eines Objektes, dass dieser Klasse entstammt. Die Prfung erfolgt von "grob" nach "fein". Nach einer
	 * <code>null</code>-Referenzabfrage wird die Instanceof methode aufgerufen, abschlieend wird der Inhalt des Objektes geprft.
	 *
	 * @param obj Referenzobjekt
	 *
	 * @return true: objekt ist gleich, false: Objekt ist nicht gleich
	 */
	public final boolean equals(Object obj) {
		if(obj == null) {
			return false;
		}
		if(!(obj instanceof FloatAttribute)) {
			return false;
		}
		float _f = ((Float)((FloatAttribute)obj).getValue()).floatValue();
		return _float == _f;
	}
}
